# ImageGenerationPipeline

Image Generation pipeline for ACRA

## Installation

1.From github
clone the codebase from GitHub
```
$ git clone https://github.com/ACRA-FL/digitgen.git
```
build the library
```
$ python setup.py bdist_wheel sdist
$ pip install -e .

